#
# Please do not update/rebuild/touch this package before asking first
# neoclust and/or daviddavid
# This package is part of the KDE Stack.
#

%define qt5_build 1
%define qt6_build 1

Summary:        Qt Cryptographic Architecture
Name:           qca
Version:        2.3.10
Release:        %mkrel 1
License:        LGPLv2+
Group:          System/Base
URL:            https://userbase.kde.org/QCA
Source0:        https://download.kde.org/stable/qca/%{version}/%{name}-%{version}.tar.xz
# Also generate pkgconfig file for qt6
Patch0:         qca-qt6-pkgconfig.patch

BuildRequires:  cmake
BuildRequires:  doxygen

%if %qt5_build
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Network)
%endif

%if %qt6_build
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Core5Compat)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6Network)
%endif

BuildRequires:  pkgconfig(botan-3)
BuildRequires:  pkgconfig(libsasl2)
BuildRequires:  pkgconfig(libpkcs11-helper-1)
BuildRequires:  pkgconfig(nss)
BuildRequires:  pkgconfig(openssl)

%description
Qt Cryptographic Architecture.

#--------------------------------------------------------------------

%if %qt5_build

%package -n %{name}-qt5
Summary:        Qt5 Cryptographic Architecture
Group:          System/Base

%description -n %{name}-qt5
Qt5 Cryptographic Architecture.

%files -n %{name}-qt5
%{_bindir}/mozcerts-qt5
%{_bindir}/qcatool-qt5
%{_libdir}/qca-qt5/
%{_mandir}/man1/qcatool-qt5.1.*

#--------------------------------------------------------------------

%define qcaqt5_major 2
%define libqcaqt5 %mklibname %{name}-qt5_ %{qcaqt5_major}

%package -n %{libqcaqt5}
Summary:        Libraries for Qt5 Cryptographic Architecture
Group:          System/Libraries

%description -n %{libqcaqt5}
Libraries for Qt5 Cryptographic Architecture.

%files -n %{libqcaqt5}
%{_libdir}/libqca-qt5.so.%{qcaqt5_major}{,.*}

#--------------------------------------------------------------------

%define qcaqt5_devel %mklibname %{name}-qt5 -d

%package -n %{qcaqt5_devel}
Summary:        Devel stuff for %{name}-qt5
Group:          Development/KDE and Qt
Requires:       %{name}-qt5 = %{version}-%{release}
Requires:       %{libqcaqt5} = %{version}-%{release}
Provides:       %{name}-qt5-devel = %{version}-%{release}

%description -n %{qcaqt5_devel}
This package contains header files needed if you wish to build applications
based on %{name}-qt5.

%files -n %{qcaqt5_devel}
%{_includedir}/Qca-qt5/
%{_libdir}/libqca-qt5.so
%{_libdir}/cmake/Qca-qt5/
%{_libdir}/pkgconfig/qca2-qt5.pc
%{_qt5_archdatadir}/mkspecs/features/crypto.prf
%endif

#--------------------------------------------------------------------

%if %qt6_build

%package -n %{name}-qt6
Summary:        Qt6 Cryptographic Architecture
Group:          Development/KDE and Qt

Obsoletes:      qca2 < 2.3.4-2
Obsoletes:      qca2-plugin-botan < 2.3.4-2
Obsoletes:      qca2-plugin-cyrus-sasl < 2.3.4-2
Obsoletes:      qca2-plugin-gcrypt < 2.3.4-2
Obsoletes:      qca2-plugin-gnupg < 2.3.4-2
Obsoletes:      qca2-plugin-logger < 2.3.4-2
Obsoletes:      qca2-plugin-nss < 2.3.4-2
Obsoletes:      qca2-plugin-openssl < 2.3.4-2
Obsoletes:      qca2-plugin-pkcs11 < 2.3.4-2
Obsoletes:      qca2-plugin-softstore < 2.3.4-2

%description -n %{name}-qt6
Qt6 Cryptographic Architecture.

%files -n %{name}-qt6
%{_bindir}/mozcerts-qt6
%{_bindir}/qcatool-qt6
%{_libdir}/qca-qt6/
%{_mandir}/man1/qcatool-qt6.1.*

#--------------------------------------------------------------------

%define qcaqt6_major 2
%define libqcaqt6 %mklibname %{name}-qt6_ %{qcaqt6_major}

%package -n %{libqcaqt6}
Summary:        Libraries for Qt6 Cryptographic Architecture
Group:          System/Libraries

Obsoletes:      %{_lib}qca2 < 2.3.4-2

%description -n %{libqcaqt6}
Libraries for Qt6 Cryptographic Architecture.

%files -n %{libqcaqt6}
%{_libdir}/libqca-qt6.so.%{qcaqt6_major}{,.*}

#--------------------------------------------------------------------

%define qcaqt6_devel %mklibname %{name}-qt6 -d

%package -n %{qcaqt6_devel}
Summary:        Devel stuff for %{name}-qt6
Group:          Development/KDE and Qt
Requires:       %{name}-qt6 = %{version}-%{release}
Requires:       %{libqcaqt6} = %{version}-%{release}
Provides:       %{name}-qt6-devel = %{version}-%{release}

Obsoletes:      %{_lib}qca-devel < 2.3.4-2

%description -n %{qcaqt6_devel}
This package contains header files needed if you wish to build applications
based on %{name}-qt6.

%files -n %{qcaqt6_devel}
%{_includedir}/Qca-qt6/
%{_libdir}/libqca-qt6.so
%{_libdir}/cmake/Qca-qt6/
%{_libdir}/pkgconfig/qca2-qt6.pc
%endif
#--------------------------------------------------------------------

%prep
%autosetup -p1

%build
%if %qt5_build
%define _vpath_builddir %{_target_platform}-qt5

%cmake_qt5 -DQCA_FEATURE_INSTALL_DIR:PATH=%{_qt5_archdatadir}/mkspecs/features
%cmake_build
%endif

%if %qt6_build
%define _vpath_builddir %{_target_platform}-qt6

%cmake_qt6 -DQCA_FEATURE_INSTALL_DIR:PATH=%{_qt6_archdatadir}/mkspecs/features -DBUILD_WITH_QT6=ON
%cmake_build
%endif

%install
%if %qt5_build
%define _vpath_builddir %{_target_platform}-qt5
%cmake_install
%endif

%if %qt6_build
%define _vpath_builddir %{_target_platform}-qt6
%cmake_install
%endif

%check
%if %qt5_build
%define _vpath_builddir %{_target_platform}-qt5
export CTEST_OUTPUT_ON_FAILURE=1
export PKG_CONFIG_PATH=%{buildroot}%{_libdir}/pkgconfig
# skip slow archs
%ifnarch %{arm}
test "$(pkg-config --modversion qca2-qt5)" = "%{version}"
%ctest --timeout 180
%endif
%endif

%if %qt6_build
%define _vpath_builddir %{_target_platform}-qt6
export CTEST_OUTPUT_ON_FAILURE=1
export PKG_CONFIG_PATH=%{buildroot}%{_libdir}/pkgconfig
# skip slow archs
%ifnarch %{arm}
test "$(pkg-config --modversion qca2-qt6)" = "%{version}"
%ctest --timeout 180
%endif
%endif


%changelog
* Thu Mar 13 2025 daviddavid <daviddavid> 2.3.10-1.mga10
+ Revision: 2163171
- new version: 2.3.10

* Fri Feb 14 2025 daviddavid <daviddavid> 2.3.9-3.mga10
+ Revision: 2148786
- rebuild for new botan3 3.7.1

* Wed Oct 23 2024 daviddavid <daviddavid> 2.3.9-2.mga10
+ Revision: 2110789
- rebuild for new botan 3.6.0

* Mon Jun 24 2024 daviddavid <daviddavid> 2.3.9-1.mga10
+ Revision: 2076442
- new version: 2.3.9

* Thu Apr 11 2024 daviddavid <daviddavid> 2.3.8-2.mga10
+ Revision: 2056456
- switch to botan-3

* Tue Jan 09 2024 daviddavid <daviddavid> 2.3.8-1.mga10
+ Revision: 2029163
- new version: 2.3.8

* Thu Aug 31 2023 daviddavid <daviddavid> 2.3.7-1.mga10
+ Revision: 1982328
- new version: 2.3.7

* Sat May 27 2023 daviddavid <daviddavid> 2.3.6-1.mga9
+ Revision: 1958646
- new version: 2.3.6

* Mon Jan 02 2023 daviddavid <daviddavid> 2.3.5-3.mga9
+ Revision: 1929362
- improve and update spec file to adapt for new qca name
- obsolete all duplicates Qt6 pkgs from old qca2 pkg, time to keep only one
- time to rename it as its original name qca

* Tue Dec 20 2022 daviddavid <daviddavid> 2.3.5-2.mga9
+ Revision: 1925433
- generate also pkgconfig file for qt6
- fix qt6 build cmake option
- update some descriptions and summaries

* Sun Nov 13 2022 daviddavid <daviddavid> 2.3.5-1.mga9
+ Revision: 1907083
- new version: 2.3.5

* Wed Sep 14 2022 neoclust <neoclust> 2.3.4-3.mga9
+ Revision: 1887928
- Build qca-qt6

* Mon Apr 04 2022 umeabot <umeabot> 2.3.4-2.mga9
+ Revision: 1843018
- Mageia 9 Mass Rebuild

* Mon Mar 07 2022 luigiwalser <luigiwalser> 2.3.4-1.mga9
+ Revision: 1789583
- 2.3.4
+ wally <wally>
- rebuild for openssl 3.0.0

* Sun Aug 08 2021 luigiwalser <luigiwalser> 2.3.3-1.mga9
+ Revision: 1740280
- 2.3.3

* Sun Apr 18 2021 kekepower <kekepower> 2.3.2-2.mga9
+ Revision: 1716675
- Rebuild for botan 2.18.0

* Sat Feb 27 2021 daviddavid <daviddavid> 2.3.2-1.mga9
+ Revision: 1692621
- new version: 2.3.2

* Thu Dec 17 2020 umeabot <umeabot> 2.3.1-5.mga8
+ Revision: 1659446
- Rebuild for new Qt5

* Sun Nov 08 2020 kekepower <kekepower> 2.3.1-4.mga8
+ Revision: 1643693
- Rebuild for Botan2, major 17

* Thu Oct 22 2020 daviddavid <daviddavid> 2.3.1-3.mga8
+ Revision: 1638596
- rebuild for new botan2 2.16.0

* Fri Jul 17 2020 daviddavid <daviddavid> 2.3.1-2.mga8
+ Revision: 1606726
- rebuild for new botan2 2.15.0

* Wed Jul 08 2020 daviddavid <daviddavid> 2.3.1-1.mga8
+ Revision: 1602901
- new version: 2.3.1

* Tue Feb 25 2020 daviddavid <daviddavid> 2.3.0-1.mga8
+ Revision: 1550267
- new version: 2.3.0

* Wed Feb 19 2020 umeabot <umeabot> 2.2.1-7.mga8
+ Revision: 1543001
- Mageia 8 Mass Rebuild

* Wed Jan 08 2020 daviddavid <daviddavid> 2.2.1-6.mga8
+ Revision: 1477283
- rebuild for new botan2 2.13.0
+ wally <wally>
- build with new cmake macros

* Fri Dec 20 2019 daviddavid <daviddavid> 2.2.1-5.mga8
+ Revision: 1469048
- rebuild for new Qt5 headers path and new mkspecs macros

* Thu Dec 05 2019 daviddavid <daviddavid> 2.2.1-4.mga8
+ Revision: 1464658
- rebuild for new botan 2.12.1

* Mon Jul 15 2019 daviddavid <daviddavid> 2.2.1-3.mga8
+ Revision: 1421548
- rebuild for new botan2 2.11.0

* Mon Jul 01 2019 daviddavid <daviddavid> 2.2.1-2.mga8
+ Revision: 1416902
- rebuild for new botan2 2.10.0

* Fri Apr 26 2019 daviddavid <daviddavid> 2.2.1-1.mga7
+ Revision: 1395566
- new version: 2.2.1

* Thu Apr 11 2019 daviddavid <daviddavid> 2.2.0-1.mga7
+ Revision: 1388329
- new version: 2.2.0
- enable botan and pkcs11 support

* Mon Apr 01 2019 umeabot <umeabot> 2.1.3-4.mga7
+ Revision: 1384148
- Qt5 Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 2.1.3-3.mga7
+ Revision: 1300637
- Mageia 7 Mass Rebuild

* Wed Sep 13 2017 cjw <cjw> 2.1.3-2.mga7
+ Revision: 1153586
- disable botan for now since it does not build with openssl 1.1
- patch1: fix build with openssl 1.1
- run tests
+ daviddavid <daviddavid>
- fix license

* Sun Aug 27 2017 daviddavid <daviddavid> 2.1.3-1.mga7
+ Revision: 1148318
- new version: 2.1.3
- update URL and Source URL
- build against compat-openssl 1.0
- enable qca-botan, qca-cyrus-sasl and qca-nss plugins

* Thu Mar 03 2016 umeabot <umeabot> 2.1.1-3.mga6
+ Revision: 983964
- Rebuild for openssl

* Tue Feb 16 2016 umeabot <umeabot> 2.1.1-2.mga6
+ Revision: 962475
- Mageia 6 Mass Rebuild

* Mon Nov 09 2015 neoclust <neoclust> 2.1.1-1.mga6
+ Revision: 899835
- New version 2.1.1

* Sun Nov 08 2015 daviddavid <daviddavid> 2.1.0.3-2.mga6
+ Revision: 899251
- remove empty lang files to fix build with latest rpm

* Sun Jul 19 2015 neoclust <neoclust> 2.1.0.3-1.mga6
+ Revision: 855255
- imported package qca-qt5

